#ifndef __VECTORPROCESSINGEXAMPLES_H
#define __VECTORPROCESSINGEXAMPLES_H

// This examples show how to call the Geographic Operation Aggregation algorithm on vector data
// Adapt the source and target datasource information to your environment!
bool AggregOGRToOGR();
bool AggregOGRToPGIS();
bool AggregPGISToPGIS();
bool AggregPGISToOGR();

bool IntersectionOGRToOGR();
bool IntersectionOGRToPGIS();
bool IntersectionPGISToPGIS();
bool IntersectionPGISToOGR();

bool BufferOGRToOGR();
bool BufferOGRToPGIS();
bool BufferPGISToPGIS();
bool BufferPGISToOGR();


#endif